<?php
defined('ABSPATH') || exit;

use Elementor\{Widget_Base, Controls_Manager, Group_Control_Typography, 
              Group_Control_Background, Group_Control_Border, Group_Control_Box_Shadow};

class Pedigree_Tree_Widget extends Widget_Base {
    public function get_name() { return 'pedigree-tree'; }
    public function get_title() { return __('Pedigree Tree', 'pedigree-tree'); }
    public function get_icon() { return 'eicon-tree'; }
    public function get_categories() { return ['general']; }
    public function get_keywords() { return ['pedigree', 'tree', 'horse', 'genealogy']; }

    protected function register_controls() {
        // Content Section
        $this->start_controls_section('section_content', [
            'label' => __('Pedigree Content', 'pedigree-tree'),
        ]);

        $horse_fields = [
            'horse_name' => ['label' => 'Horse Name (Focus)', 'default' => '*'],
            'parent1_name' => ['label' => 'Parent 1 Name', 'default' => '*'],
            'parent2_name' => ['label' => 'Parent 2 Name', 'default' => '*'],
            'grandparent1_name' => ['label' => 'Grandparent 1 (Parent 1)', 'default' => '*'],
            'grandparent2_name' => ['label' => 'Grandparent 2 (Parent 1)', 'default' => '*'],
            'grandparent3_name' => ['label' => 'Grandparent 1 (Parent 2)', 'default' => '*'],
            'grandparent4_name' => ['label' => 'Grandparent 2 (Parent 2)', 'default' => '*'],
        ];

        for ($i = 1; $i <= 8; $i++) {
            $horse_fields["great_grandparent{$i}_name"] = [
                'label' => "Great-Grandparent {$i} (Grandparent " . ceil($i/2) . ')',
                'default' => "Example GG{$i}"
            ];
        }

        foreach ($horse_fields as $key => $field) {
            $this->add_control($key, [
                'label' => __($field['label'], 'pedigree-tree'),
                'type' => Controls_Manager::TEXT,
                'default' => $field['default'],
                'label_block' => true,
            ]);
        }

        $this->end_controls_section();

        // Layout Section
        $this->start_controls_section('section_layout', [
            'label' => __('Layout', 'pedigree-tree'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_control('layout_style', [
            'label' => __('Tree Layout', 'pedigree-tree'),
            'type' => Controls_Manager::SELECT,
            'default' => 'pyramid',
            'options' => [
                'pyramid' => __('Pyramid', 'pedigree-tree'),
                'stacked' => __('Stacked', 'pedigree-tree'),
                'compact' => __('Compact', 'pedigree-tree'),
            ],
            'prefix_class' => 'pedigree-layout-',
        ]);

        $this->add_responsive_control('tree_alignment', [
            'label' => __('Alignment', 'pedigree-tree'),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => ['title' => __('Left'), 'icon' => 'eicon-text-align-left'],
                'center' => ['title' => __('Center'), 'icon' => 'eicon-text-align-center'],
                'right' => ['title' => __('Right'), 'icon' => 'eicon-text-align-right'],
            ],
            'default' => 'center',
            'selectors' => ['{{WRAPPER}} .pedigree-tree' => 'align-items: {{VALUE}}'],
        ]);

        $this->end_controls_section();

        // Style Section
        $this->start_controls_section('section_style', [
            'label' => __('Style', 'pedigree-tree'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_group_control(Group_Control_Typography::get_type(), [
            'name' => 'horse_typography',
            'label' => __('Typography', 'pedigree-tree'),
            'selector' => '{{WRAPPER}} .horse',
        ]);

        $this->add_responsive_control('horse_text_color', [
            'label' => __('Text Color', 'pedigree-tree'),
            'type' => Controls_Manager::COLOR,
            'default' => '#ffffff',
            'selectors' => ['{{WRAPPER}} .horse' => 'color: {{VALUE}}'],
        ]);

        $this->add_group_control(Group_Control_Background::get_type(), [
            'name' => 'tree_background',
            'label' => __('Tree Background', 'pedigree-tree'),
            'types' => ['classic', 'gradient'],
            'selector' => '{{WRAPPER}} .pedigree-tree',
        ]);

        $this->start_controls_tabs('horse_styles');
        
        $this->start_controls_tab('horse_normal', ['label' => __('Normal', 'pedigree-tree')]);
        
        $this->add_group_control(Group_Control_Background::get_type(), [
            'name' => 'horse_background',
            'label' => __('Horse Background', 'pedigree-tree'),
            'types' => ['classic', 'gradient'],
            'selector' => '{{WRAPPER}} .horse',
        ]);

        $this->add_group_control(Group_Control_Border::get_type(), [
            'name' => 'horse_border',
            'selector' => '{{WRAPPER}} .horse',
        ]);

        $this->add_group_control(Group_Control_Box_Shadow::get_type(), [
            'name' => 'horse_box_shadow',
            'selector' => '{{WRAPPER}} .horse',
        ]);

        $this->end_controls_tab();

        $this->start_controls_tab('horse_hover', ['label' => __('Hover', 'pedigree-tree')]);
        
        $this->add_group_control(Group_Control_Background::get_type(), [
            'name' => 'horse_background_hover',
            'label' => __('Hover Background', 'pedigree-tree'),
            'types' => ['classic', 'gradient'],
            'selector' => '{{WRAPPER}} .horse:hover',
        ]);

        $this->add_control('horse_text_color_hover', [
            'label' => __('Hover Text Color', 'pedigree-tree'),
            'type' => Controls_Manager::COLOR,
            'selectors' => ['{{WRAPPER}} .horse:hover' => 'color: {{VALUE}}'],
        ]);

        $this->add_group_control(Group_Control_Box_Shadow::get_type(), [
            'name' => 'horse_box_shadow_hover',
            'selector' => '{{WRAPPER}} .horse:hover',
        ]);

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_responsive_control('horse_padding', [
            'label' => __('Padding', 'pedigree-tree'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em', '%'],
            'selectors' => ['{{WRAPPER}} .horse' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}'],
        ]);

        $this->add_responsive_control('horse_margin', [
            'label' => __('Margin', 'pedigree-tree'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em', '%'],
            'selectors' => ['{{WRAPPER}} .horse' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}'],
        ]);

        $this->add_control('hr_lines', ['type' => Controls_Manager::DIVIDER]);

        $this->add_responsive_control('connection_line_color', [
            'label' => __('Line Color', 'pedigree-tree'),
            'type' => Controls_Manager::COLOR,
            'default' => '#ff8c00',
            'selectors' => ['{{WRAPPER}} .connection-line' => 'background-color: {{VALUE}}'],
        ]);

        $this->add_responsive_control('connection_line_thickness', [
            'label' => __('Line Thickness', 'pedigree-tree'),
            'type' => Controls_Manager::SLIDER,
            'range' => ['px' => ['min' => 1, 'max' => 20]],
            'default' => ['size' => 2],
            'selectors' => ['{{WRAPPER}} .connection-line' => 'width: {{SIZE}}px; stroke-width: {{SIZE}}px'],
        ]);

        $this->add_responsive_control('line_height', [
            'label' => __('Line Height', 'pedigree-tree'),
            'type' => Controls_Manager::SLIDER,
            'range' => ['px' => ['min' => 10, 'max' => 100]],
            'default' => ['size' => 20],
            'selectors' => ['{{WRAPPER}} .connection-line' => 'min-height: {{SIZE}}px'],
        ]);

        $this->add_control('line_style', [
            'label' => __('Line Style', 'pedigree-tree'),
            'type' => Controls_Manager::SELECT,
            'default' => 'solid',
            'options' => [
                'solid' => __('Solid', 'pedigree-tree'),
                'dashed' => __('Dashed', 'pedigree-tree'),
                'dotted' => __('Dotted', 'pedigree-tree'),
            ],
            'selectors' => [
                '{{WRAPPER}} .connection-line' => 'border-style: {{VALUE}}; background: none; border-width: {{connection_line_thickness.SIZE}}px',
                '{{WRAPPER}} .connection-line.solid' => 'background-color: {{connection_line_color.VALUE}}; border: none',
            ],
        ]);

        $this->add_responsive_control('generation_spacing', [
            'label' => __('Generation Spacing', 'pedigree-tree'),
            'type' => Controls_Manager::SLIDER,
            'range' => ['px' => ['min' => 0, 'max' => 100]],
            'default' => ['size' => 10],
            'selectors' => [
                '{{WRAPPER}} .generation-row' => 'gap: {{SIZE}}px',
                '{{WRAPPER}} .parents' => 'margin-top: {{SIZE}}px',
                '{{WRAPPER}} .grandparents' => 'margin-top: calc({{SIZE}}px * 2)',
                '{{WRAPPER}} .great-grandparents' => 'margin-top: calc({{SIZE}}px * 3)',
            ],
        ]);

        $this->add_control('horse_hover_animation', [
            'label' => __('Hover Animation', 'pedigree-tree'),
            'type' => Controls_Manager::SELECT,
            'default' => 'none',
            'options' => [
                'none' => __('None', 'pedigree-tree'),
                'scale' => __('Scale', 'pedigree-tree'),
                'fade' => __('Fade', 'pedigree-tree'),
                'lift' => __('Lift', 'pedigree-tree'),
            ],
            'prefix_class' => 'pedigree-tree-hover-',
        ]);

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="pedigree-tree">
            <div class="generation-row">
                <div class="horse focus"><?php echo esc_html($settings['horse_name']); ?></div>
            </div>
            <div class="generation-row parents">
                <?php foreach (['parent1_name', 'parent2_name'] as $parent): ?>
                    <div class="parent-line">
                        <div class="horse"><?php echo esc_html($settings[$parent]); ?></div>
                        <div class="connection-line vertical <?php echo esc_attr($settings['line_style']); ?>"></div>
                    </div>
                <?php endforeach; ?>
            </div>
            <div class="generation-row grandparents">
                <?php for ($i = 1; $i <= 4; $i++): ?>
                    <div class="grandparent-line">
                        <div class="horse"><?php echo esc_html($settings["grandparent{$i}_name"]); ?></div>
                        <div class="connection-line vertical <?php echo esc_attr($settings['line_style']); ?>"></div>
                    </div>
                <?php endfor; ?>
            </div>
            <div class="generation-row great-grandparents">
                <?php for ($i = 1; $i <= 8; $i++): ?>
                    <div class="great-grandparent-line">
                        <div class="horse"><?php echo esc_html($settings["great_grandparent{$i}_name"]); ?></div>
                    </div>
                <?php endfor; ?>
            </div>
        </div>
        <?php
    }
}