<?php
/**
 * Plugin Name: Horse Pedigree Elementor
 * Description: Elementor-Widget für einen Pedigree-Stammbaum mit horizontalem Layout (oben/unten) und versetztem „vertikalen“ Layout (links nach rechts) via CSS Grid. Inkl. Style-Kontrollen (Farbe, Typografie).
 * Version: 1.1
 * Author: Dein Name
 * Text Domain: horse-pedigree-elementor
 */

namespace HorsePedigreeElementor;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!defined('ABSPATH')) {
    exit; // Sicherheitsprüfung
}

// Prüfung auf Elementor und Admin-Meldung
if (!did_action('elementor/loaded')) {
    add_action('admin_notices', function() {
        printf(
            '<div class="notice notice-warning is-dismissible"><p>%s</p></div>',
            esc_html__('Horse Pedigree Elementor benötigt Elementor. Bitte installiere und aktiviere Elementor.', 'horse-pedigree-elementor')
        );
    });
    return;
}

// Widget-Registrierung
add_action('elementor/widgets/register', function($widgets_manager) {

    class Horse_Pedigree_Widget extends Widget_Base {

        public function get_name() {
            return 'horse_pedigree';
        }

        public function get_title() {
            return __('Horse Pedigree', 'horse-pedigree-elementor');
        }

        public function get_icon() {
            return 'eicon-network';
        }

        public function get_categories() {
            return ['general'];
        }

        /**
         * Definiert die Inhaltselemente (Controls) im Tab "Content"
         */
        protected function register_controls() {

            /**
             * CONTENT SECTION
             */
            $this->start_controls_section(
                'content_section',
                [
                    'label' => __('Inhalt', 'horse-pedigree-elementor'),
                    'tab'   => Controls_Manager::TAB_CONTENT,
                ]
            );

            // Layout-Auswahl
            $this->add_control(
                'layout',
                [
                    'label'   => __('Layout', 'horse-pedigree-elementor'),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'horizontal',
                    'options' => [
                        'horizontal' => __('Horizontal (Oben/Unten)', 'horse-pedigree-elementor'),
                        'vertical'   => __('Vertikal (Links→Rechts)', 'horse-pedigree-elementor'),
                    ],
                ]
            );

            // Pferde-Daten (Focus, Eltern, Großeltern, Urgroßeltern)
            $horses = [
                'focus' => ['label' => __('Fokus-Pferd', 'horse-pedigree-elementor'), 'default' => 'Horse Name (Focus)'],
                'parent1' => ['label' => __('Elternteil 1', 'horse-pedigree-elementor'), 'default' => 'Parent 1'],
                'parent2' => ['label' => __('Elternteil 2', 'horse-pedigree-elementor'), 'default' => 'Parent 2'],
                'grandparent1' => ['label' => __('Großelternteil 1', 'horse-pedigree-elementor'), 'default' => 'Grandparent 1'],
                'grandparent2' => ['label' => __('Großelternteil 2', 'horse-pedigree-elementor'), 'default' => 'Grandparent 2'],
                'grandparent3' => ['label' => __('Großelternteil 3', 'horse-pedigree-elementor'), 'default' => 'Grandparent 3'],
                'grandparent4' => ['label' => __('Großelternteil 4', 'horse-pedigree-elementor'), 'default' => 'Grandparent 4'],
                'ggparent1' => ['label' => __('Urgroßelternteil 1', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 1'],
                'ggparent2' => ['label' => __('Urgroßelternteil 2', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 2'],
                'ggparent3' => ['label' => __('Urgroßelternteil 3', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 3'],
                'ggparent4' => ['label' => __('Urgroßelternteil 4', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 4'],
                'ggparent5' => ['label' => __('Urgroßelternteil 5', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 5'],
                'ggparent6' => ['label' => __('Urgroßelternteil 6', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 6'],
                'ggparent7' => ['label' => __('Urgroßelternteil 7', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 7'],
                'ggparent8' => ['label' => __('Urgroßelternteil 8', 'horse-pedigree-elementor'), 'default' => 'Great-Grandparent 8'],
            ];

            foreach ($horses as $key => $data) {
                $this->add_control(
                    $key,
                    [
                        'label' => $data['label'],
                        'type' => Controls_Manager::TEXT,
                        'default' => __($data['default'], 'horse-pedigree-elementor'),
                    ]
                );
            }

            $this->end_controls_section();


            /**
             * STYLE SECTION: Grundlegende Style-Optionen
             */
            $this->start_controls_section(
                'style_section',
                [
                    'label' => __('Allgemeines Styling', 'horse-pedigree-elementor'),
                    'tab'   => Controls_Manager::TAB_STYLE,
                ]
            );

            // Typografie für alle "horse"-Elemente
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'horse_typography',
                    'label'    => __('Pferde-Typografie', 'horse-pedigree-elementor'),
                    'selector' => '{{WRAPPER}} .horse-pedigree .horse',
                ]
            );

            // Hintergrundfarbe für alle "horse"-Elemente
            $this->add_control(
                'horse_bg_color',
                [
                    'label'     => __('Hintergrundfarbe Pferde-Boxen', 'horse-pedigree-elementor'),
                    'type'      => Controls_Manager::COLOR,
                    'default'   => '#CCCCCC',
                    'selectors' => [
                        '{{WRAPPER}} .horse-pedigree .horse:not(.focus)' => 'background-color: {{VALUE}};',
                    ],
                ]
            );

            // Textfarbe für alle "horse"-Elemente
            $this->add_control(
                'horse_text_color',
                [
                    'label'     => __('Textfarbe Pferde-Boxen', 'horse-pedigree-elementor'),
                    'type'      => Controls_Manager::COLOR,
                    'default'   => '#000000',
                    'selectors' => [
                        '{{WRAPPER}} .horse-pedigree .horse:not(.focus)' => 'color: {{VALUE}};',
                    ],
                ]
            );

            // Abstände (Padding) für alle "horse"-Elemente
            $this->add_responsive_control(
                'horse_padding',
                [
                    'label'      => __('Innenabstand (Padding)', 'horse-pedigree-elementor'),
                    'type'       => Controls_Manager::DIMENSIONS,
                    'size_units' => ['px', 'em', '%'],
                    'default'    => [
                        'top'    => '10',
                        'right'  => '20',
                        'bottom' => '10',
                        'left'   => '20',
                        'unit'   => 'px',
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .horse-pedigree .horse:not(.focus)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->end_controls_section();


            /**
             * STYLE SECTION: Fokus-Pferd
             */
            $this->start_controls_section(
                'focus_style_section',
                [
                    'label' => __('Fokus-Pferd', 'horse-pedigree-elementor'),
                    'tab'   => Controls_Manager::TAB_STYLE,
                ]
            );

            // Fokus-Typografie
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'focus_typography',
                    'label'    => __('Fokus-Pferd Typografie', 'horse-pedigree-elementor'),
                    'selector' => '{{WRAPPER}} .horse-pedigree .focus',
                ]
            );

            // Fokus-Hintergrund
            $this->add_control(
                'focus_bg_color',
                [
                    'label'     => __('Hintergrundfarbe Fokus-Pferd', 'horse-pedigree-elementor'),
                    'type'      => Controls_Manager::COLOR,
                    'default'   => '#ff8c00',
                    'selectors' => [
                        '{{WRAPPER}} .horse-pedigree .focus' => 'background-color: {{VALUE}};',
                    ],
                ]
            );

            // Fokus-Textfarbe
            $this->add_control(
                'focus_text_color',
                [
                    'label'     => __('Textfarbe Fokus-Pferd', 'horse-pedigree-elementor'),
                    'type'      => Controls_Manager::COLOR,
                    'default'   => '#ffffff',
                    'selectors' => [
                        '{{WRAPPER}} .horse-pedigree .focus' => 'color: {{VALUE}};',
                    ],
                ]
            );

            // Fokus-Padding
            $this->add_responsive_control(
                'focus_padding',
                [
                    'label'      => __('Innenabstand (Padding) Fokus', 'horse-pedigree-elementor'),
                    'type'       => Controls_Manager::DIMENSIONS,
                    'size_units' => ['px', 'em', '%'],
                    'default'    => [
                        'top'    => '10',
                        'right'  => '20',
                        'bottom' => '10',
                        'left'   => '20',
                        'unit'   => 'px',
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .horse-pedigree .focus' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->end_controls_section();

        }

        protected function render() {
            $settings = $this->get_settings_for_display();
            $layout = $settings['layout'];
            $layout_class = ($layout === 'vertical') ? 'layout-vertical' : 'layout-horizontal';

            ?>
            <!-- Minimales Inline-CSS -->
            <style>
                .horse-pedigree {
                    margin: 0 auto;
                    max-width: 1200px;
                }
                .horse {
                    border-radius: 4px;
                    text-align: center;
                    font-weight: bold;
                    /* Hintergrund- und Textfarben kommen aus den Style-Kontrollen */
                }
                .focus {
                    /* Hintergrund- und Textfarben kommen aus den Style-Kontrollen */
                }
                .connection-line {
                    width: 2px;
                    background: red;
                    margin: 10px auto;
                    height: 40px;
                }
                /* =============== HORIZONTAL =============== */
                .layout-horizontal .generation-row {
                    display: flex;
                    justify-content: center;
                    margin: 20px 0;
                }
                .layout-horizontal .horse {
                    margin: 0 10px;
                }
                /* =============== VERTIKAL (GRID) =============== */
                .layout-vertical .grid-container {
                    display: grid;
                    grid-template-columns: repeat(4, auto);
                    grid-template-rows: repeat(8, auto);
                    gap: 1.5rem;
                    justify-content: center;
                    align-items: center;
                }
                /* Positionen im Grid (4 Spalten x 8 Reihen) */
                .layout-vertical .focus-pos {grid-column: 1; grid-row: 4;}
                .layout-vertical .parent1-pos {grid-column: 2; grid-row: 2;}
                .layout-vertical .parent2-pos {grid-column: 2; grid-row: 6;}
                .layout-vertical .grandparent1-pos {grid-column: 3; grid-row: 1;}
                .layout-vertical .grandparent2-pos {grid-column: 3; grid-row: 3;}
                .layout-vertical .grandparent3-pos {grid-column: 3; grid-row: 5;}
                .layout-vertical .grandparent4-pos {grid-column: 3; grid-row: 7;}
                .layout-vertical .ggparent1-pos {grid-column: 4; grid-row: 1;}
                .layout-vertical .ggparent2-pos {grid-column: 4; grid-row: 2;}
                .layout-vertical .ggparent3-pos {grid-column: 4; grid-row: 3;}
                .layout-vertical .ggparent4-pos {grid-column: 4; grid-row: 4;}
                .layout-vertical .ggparent5-pos {grid-column: 4; grid-row: 5;}
                .layout-vertical .ggparent6-pos {grid-column: 4; grid-row: 6;}
                .layout-vertical .ggparent7-pos {grid-column: 4; grid-row: 7;}
                .layout-vertical .ggparent8-pos {grid-column: 4; grid-row: 8;}
                .layout-vertical .connection-line {display: none;}

                @media (max-width: 768px) {
                    .layout-horizontal .generation-row {
                        flex-direction: column;
                    }
                    .layout-vertical .grid-container {
                        grid-template-columns: 1fr;
                        grid-template-rows: auto;
                    }
                }
            </style>

            <div class="horse-pedigree <?php echo esc_attr($layout_class); ?>">
                <?php if ($layout === 'horizontal'): ?>
                    <!-- HORIZONTALES Layout -->
                    <div class="generation-row focus-generation">
                        <div class="horse focus"><?php echo esc_html($settings['focus']); ?></div>
                    </div>

                    <div class="generation-row parents">
                        <?php foreach (['parent1', 'parent2'] as $parent): ?>
                            <div class="parent-line">
                                <div class="connection-line"></div>
                                <div class="horse"><?php echo esc_html($settings[$parent]); ?></div>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <div class="generation-row grandparents">
                        <?php for ($i = 1; $i <= 4; $i++): ?>
                            <div class="grandparent-line">
                                <div class="connection-line"></div>
                                <div class="horse"><?php echo esc_html($settings["grandparent$i"]); ?></div>
                            </div>
                        <?php endfor; ?>
                    </div>

                    <div class="generation-row great-grandparents">
                        <?php for ($i = 1; $i <= 8; $i++): ?>
                            <div class="great-grandparent-line">
                                <div class="connection-line"></div>
                                <div class="horse"><?php echo esc_html($settings["ggparent$i"]); ?></div>
                            </div>
                        <?php endfor; ?>
                    </div>

                <?php else: ?>
                    <!-- VERTIKALES (GRID) Layout -->
                    <div class="grid-container">
                        <!-- Fokus -->
                        <div class="horse focus focus-pos">
                            <?php echo esc_html($settings['focus']); ?>
                        </div>
                        <!-- Eltern -->
                        <div class="horse parent1-pos"><?php echo esc_html($settings['parent1']); ?></div>
                        <div class="horse parent2-pos"><?php echo esc_html($settings['parent2']); ?></div>
                        <!-- Großeltern -->
                        <?php for ($i = 1; $i <= 4; $i++): ?>
                            <div class="horse grandparent<?php echo $i; ?>-pos">
                                <?php echo esc_html($settings["grandparent$i"]); ?>
                            </div>
                        <?php endfor; ?>
                        <!-- Urgroßeltern -->
                        <?php for ($i = 1; $i <= 8; $i++): ?>
                            <div class="horse ggparent<?php echo $i; ?>-pos">
                                <?php echo esc_html($settings["ggparent$i"]); ?>
                            </div>
                        <?php endfor; ?>
                    </div>
                <?php endif; ?>
            </div>
            <?php
        }
    }

    $widgets_manager->register(new Horse_Pedigree_Widget());
});
